Index: flashrom-me/flash.h
===================================================================
--- flashrom-me.orig/flash.h
+++ flashrom-me/flash.h
@@ -226,12 +226,25 @@ int write_buf_to_file(unsigned char *buf
 #define OK 0
 #define NT 1    /* Not tested */
 
+/* what to do in case of an error */
+enum error_action {
+	error_fail,	/* fail immediately */
+	error_ignore,	/* non-fatal error; continue */
+};
+
 /* Something happened that shouldn't happen, but we can go on. */
 #define ERROR_NONFATAL 0x100
 
 /* Something happened that shouldn't happen, we'll abort. */
 #define ERROR_FATAL -0xee
 
+/* Operation failed due to access restriction set in programmer or flash chip */
+#define ACCESS_DENIED -7
+extern enum error_action access_denied_action;
+
+/* convenience function for checking return codes */
+extern int ignore_error(int x);
+
 /* cli_output.c */
 /* Let gcc and clang check for correct printf-style format strings. */
 int print(int type, const char *fmt, ...) __attribute__((format(printf, 2, 3)));
Index: flashrom-me/flashrom.c
===================================================================
--- flashrom-me.orig/flashrom.c
+++ flashrom-me/flashrom.c
@@ -42,6 +42,25 @@ const char flashrom_version[] = FLASHROM
 char *chip_to_probe = NULL;
 int verbose = 0;
 
+/* error handling stuff */
+enum error_action access_denied_action = error_ignore;
+
+/* returns boolean (1 if caller should ignore error code, 0 if not) */
+int ignore_error(int err) {
+	int ret = 0;
+
+	switch(err) {
+	case ACCESS_DENIED:
+		if (access_denied_action == error_ignore)
+			ret = 1;
+		break;
+	default:
+		break;
+	}
+
+	return ret;
+}
+
 static enum programmer programmer = PROGRAMMER_INVALID;
 
 static char *programmer_param = NULL;
